@@ -41,22 +41,19 @@ inline void addUrlQueryItems(QUrlQuery *query, const QVariantMap &map) {
     qDebug() << "addUrlQueryItems:" << query << map;
 #endif
     QMapIterator<QString, QVariant> iterator(map);
-    QByteArray value;
-    
+        
     while (iterator.hasNext()) {
         iterator.next();
         
         switch (iterator.value().type()) {
         case QVariant::String:
         case QVariant::ByteArray:
-            value = iterator.value().toString().toUtf8();
+            query->addQueryItem(iterator.key(), iterator.value().toString());
             break;
         default:
-            value = QtJson::Json::serialize(iterator.value());
+            query->addQueryItem(iterator.key(), QtJson::Json::serialize(iterator.value()));
             break;
-        }
-        
-        query->addQueryItem(iterator.key(), value);
+        }        
     }
 }
 #else
@@ -65,22 +62,19 @@ inline void addUrlQueryItems(QUrl *url, const QVariantMap &map) {
     qDebug() << "addUrlQueryItems:" << url << map;
 #endif
     QMapIterator<QString, QVariant> iterator(map);
-    QByteArray value;
-    
+        
     while (iterator.hasNext()) {
         iterator.next();
         
         switch (iterator.value().type()) {
         case QVariant::String:
         case QVariant::ByteArray:
-            value = iterator.value().toString().toUtf8();
+            url->addQueryItem(iterator.key(), iterator.value().toString());
             break;
         default:
-            value = QtJson::Json::serialize(iterator.value());
+            url->addQueryItem(iterator.key(), QtJson::Json::serialize(iterator.value()));
             break;
-        }
-        
-        url->addQueryItem(iterator.key(), value);
+        }        
     }
 }
 #endif
@@ -90,46 +84,40 @@ inline void addRequestHeaders(QNetworkRequest *request, const QVariantMap &map)
     qDebug() << "addRequestHeaders:" << request->url() << map;
 #endif
     QMapIterator<QString, QVariant> iterator(map);
-    QByteArray value;
-    
+        
     while (iterator.hasNext()) {
         iterator.next();
         
         switch (iterator.value().type()) {
         case QVariant::String:
         case QVariant::ByteArray:
-            value = iterator.value().toString().toUtf8();
+            request->setRawHeader(iterator.key().toUtf8(), iterator.value().toByteArray());
             break;
         default:
-            value = QtJson::Json::serialize(iterator.value());
+            request->setRawHeader(iterator.key().toUtf8(), QtJson::Json::serialize(iterator.value()));
             break;
         }
-        
-        request->setRawHeader(iterator.key().toUtf8(), value);
     }
 }
 
 inline void addPostBody(QString *body, const QVariantMap &map) {
-#ifdef QVIMEO_DEBUG
+#ifdef QYOUTUBE_DEBUG
     qDebug() << "addPostBody:" << body << map;
 #endif
     QMapIterator<QString, QVariant> iterator(map);
-    QByteArray value;
-    
+        
     while (iterator.hasNext()) {
         iterator.next();
         
         switch (iterator.value().type()) {
         case QVariant::String:
         case QVariant::ByteArray:
-            value = iterator.value().toString().toUtf8();
+            body->append(iterator.key() + "=" + iterator.value().toString());
             break;
         default:
-            value = QtJson::Json::serialize(iterator.value());
+            body->append(iterator.key() + "=" + QtJson::Json::serialize(iterator.value()));
             break;
-        }
-        
-        body->append(iterator.key() + "=" + value);
+        }        
         
         if (iterator.hasNext()) {
             body->append("&");
